@@ -71,8 +71,9 @@ type MigPlanSpec struct {
 // MigPlanStatus defines the observed state of MigPlan
 type MigPlanStatus struct {
 	Conditions
-	Incompatible   `json:",inline"`
-	ObservedDigest string `json:"observedDigest,omitempty"`
+	Incompatible      `json:",inline"`
+	ObservedDigest    string   `json:"observedDigest,omitempty"`
+	ExcludedResources []string `json:"excludedResources,omitempty"`
 }
 
 // +genclient
@@ -691,6 +692,16 @@ func (r *MigPlan) HasConflict(plan *MigPlan) bool {
 	return false
 }
 
+// GetDestinationNamespaces get destination namespaces without mapping
+func (r *MigPlan) IsResourceExcluded(resource string) bool {
+	for _, excludedResource := range r.Status.ExcludedResources {
+		if resource == excludedResource {
+			return true
+		}
+	}
+	return false
+}
+
 //
 //
 // PV list
@@ -874,6 +885,13 @@ func (r *PersistentVolumes) DeletePv(names ...string) {
 	}
 }
 
+// Reset PVs collection.
+func (r *PersistentVolumes) ResetPvs() {
+	r.init()
+	r.List = []PV{}
+	r.buildIndex()
+}
+
 // Convert name to a DNS_LABEL-compliant string
 // DNS_LABEL:  This is a string, no more than 63 characters long, that conforms
 //     to the definition of a "label" in RFCs 1035 and 1123. This is captured
